function retval = detection_probability_generic_b (Nc, Nap, Pt, Pdef, Pm, RepA, RepT, terrainX, d, R)
% Detection probability for a d-distance Type-2 edge (R < d <= 2R) in a 
% client-centric scheme.
% Input:
% - Nc: num clients
% - Nap: num aps
% - Pt: Probability a client is truthful
% - Pdef: Probability an attacker defects (attacks)
% - Pm: Probability an AP is managed
% - RepA: avg attacker reputation
% - RepT: avg truthful user reputation
% - terrainX: terrain size
% - d: edge distance
% - R: range
%
%
% Copyright (c) 2011, Pantelis A. Frangoudis
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
%
%    * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

    % Managed AP intensity
    Lmap = (Pm.*Nap) / (terrainX^2);
    Lap = Nap / (terrainX^2);
    
    % Edge miss probability:
    % 1. 0 managed APs
    % 2. Less than ceil[1/R] reports
        
    La = Nc.*(1 - Pt) .* (1 - Pdef)./terrainX^2;
    Lt = Nc.*Pt./terrainX^2;
    Lm = Pm .* Lap;

    sum = 0;
    if RepT == 0 && RepA == 0
        sum = 1;
    else if RepT == 0
            for j=0:floor( 1./RepA )
                sum = sum + poisspdf(j, La.*overlap_area(d,R));
            end
        else if RepA == 0
            for j=0:floor( 1./RepT )
                sum = sum + poisspdf(j, Lt.*overlap_area(d,R));
            end
            else
                for i=0:floor(1./RepT)
                    for j=0:floor( (1 - RepT.*i)./RepA )
                        sum = sum + poisspdf(i, Lt.*overlap_area(d,R)).*poisspdf(j, La.*overlap_area(d,R));
                    end
                end
            end
        end
    end
    retval = 1 - sum.*poisspdf(0, Lm.*overlap_area(d,R));
end
