function [retval] = performance_lc(Pt, Pdef, Pm, B, Nc, Nap, terrainX, R)
% Performance plots for varying client densities.
% Pt: Truthful probability
% Pdef: Defection probability for an attacker
% Pm: Probability an AP is managed
% B: discount factor
% Nc: #clients
% Nap: #APs
% terrainX: size of terrain
% R: range/radius
    styles = ['rs', 'b*', 'k+'];
    counter = 0;
    for k=Nc:10000:Nc+20000
        Nc = k;
        counter = counter + 1;
        R1 = 0.0;
        R2 = 0.0;
        
        rounds = 100;

        for i=1:rounds
            % avg truthful user reputation
            repsT(i) = R1;
            % avg potential attacker reputation
            repsA(i) = R2;
            
            % efficiency of the AP-centric scheme
            toplotAC(i) = efficiency_ap_centric(Nc, Nap, Pm, terrainX, R);

            % efficiency of the client-centric scheme
            theround = efficiency(Nc, Nap, Pt, Pdef, Pm, R2, R1, terrainX, R);

            % an isolated user does not contribute reports and his reputation
            % is not discounted
            Pi = Pisolated(Nap, R, Pm, terrainX);

            % scores for round i
            Tscore = score(Nc, Nap, Pt, Pdef, Pm, R2, R1, 'T', terrainX, R);
            Ascore = score(Nc, Nap, Pt, Pdef, Pm, R2, R1, 'A', terrainX, R);

            % reputation update for truthful users
            R1 = Pi .* R1 + (1.0 - Pi) .* (B * R1 + (1.0 - B) * Tscore);

            % reputation of attackers
            R2 = Pi .* R2 + (1.0 - Pi) .* (Pdef .* B .* R2 + (1 - Pdef) .* ( B .* R2 + (1 - B) .* Ascore));

            toplot(i) = theround;
            AC(counter,i) = toplotAC(i);
            CC(counter,i) = toplot(i);
            scoreA(i) = Ascore;
            scoreT(i) = Tscore;
        end

    end
    
    x=1:rounds;
        
    % plot detection probability
    ah = axes();
    set(ah, 'FontSize', 22);
    plot(x, CC(1,:), 'k^'); 
    hold on
    plot(x, CC(2,:), 'rx'); 
    hold on
    plot(x, CC(3,:), 'b*'); 
    hold on
    plot(x, AC(1,:), 'k'); 
    hold on
    plot(x, AC(2,:), 'r'); 
    hold on
    plot(x, AC(3,:), 'b');     
    hold off;
    axis ([0 rounds 0.0 1.0]);
    title({'Filtering efficiency', '2123 APs/km^2, p_{m}=0.07, p_t=0.5, p_a=0.9'});
    xlabel('Round');
    ylabel('Ratio of discovered edges');
    leg = legend('10000 clients/km^2 (UC)', '20000 clients/km^2 (UC)', '30000 clients/km^2 (UC)', '10000 clients/km^2 (AC)', '20000 clients/km^2 (AC)', '30000 clients/km^2 (AC)', 6, 'Location', 'SouthEast');
    set(leg, 'FontSize', 14);
    print -depsc -r600 plots/AUEB-clidensity.eps
end
