function retval = score_d (Nc, Nap, Pt, Pdef, Pm, RepA, RepT, type, terrainX, d, R)
% Probability that a d-distance Type-2 edge reported by a user of a
% specific type (attacker or truthful) survives filtering.
% In other words, score_d = Pr{discovered | reported by at least a client} = Pr{discovered AND reported by >= 1 client} / Pr {>= 1 client}
% Input:
% Nc: number of clients
% Nap: number of APs
% Pt: Probability a user is always truthful
% Pdef: Probability a potential attacker attacks at this round
% Pm: Probability an AP is managed
% RepA: Mean reputation of a potential attacker
% RepT: Mean reputation of a truthful user
% type: should be either 'A' (potential attacker) or 'T' (truthful)
% terrainX: size of terrain (length of terrain edge in m)
% d: Edge distance (distance between two APs)
% R: cell radius
%
% Copyright (c) 2011, Pantelis A. Frangoudis
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
%
%    * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

    La = Nc.*(1 - Pt) .* (1 - Pdef)./terrainX^2;
    Lt = Nc.*Pt./terrainX^2;
    Lap = Nap ./ terrainX^2;
    Lm = Pm .* Lap;
    %A: at least one managed AP in overlap area
    A = 1 - poisspdf(0, Lm.*overlap_area(d,R));
    
    %X: at least one reporter of specific type in overlap area
    if (type == 'A') 
        X = 1 - poisspdf (0, La.*overlap_area(d, R));
    else
        X = 1 - poisspdf (0, Lt.*overlap_area(d, R));
    end

    if type == 'A'
       limitdownA = 1;
       limitdownT = 0;
    else
       limitdownA = 0;
       limitdownT = 1;
    end
        
    %detection sum
    sum = 0;
    if RepT == 0 && RepA == 0
        sum = 1;
    else 
        for i=limitdownT:floor(1./RepT)
            for j=limitdownA:floor( (1 - RepT.*i)./RepA)
                sum = sum + poisspdf(i, Lt.*overlap_area(d,R)).*poisspdf(j, La.*overlap_area(d,R));
            end
        end
    end

    if (RepT == 0 && RepA == 0)
        retval = A;
    else
        retval = ( A.*X + (1 - A) .* (1 - sum - (1 - X) ) )./ X;        
    end
end
